#define OPEQ MFB_OPEQ_WHITE
#define MFBPOLYGLYPHBLT mfbPolyGlyphBltWhite
#include "../../mfb/mfbplygblt.c"
